[![PyPI](https://img.shields.io/pypi/v/dialz?color=blue)](https://pypi.org/project/dialz/)
[![license](https://img.shields.io/badge/License-MIT-brightgreen.svg)](https://github.com/cardiffnlp/dialz/blob/master/LICENSE) 

# Dialz: A Python Toolkit for Steering Vectors

Docs: [https://cardiffnlp.github.io/dialz/](https://cardiffnlp.github.io/dialz/)

Paper: [https://www.arxiv.org/abs/2505.06262](https://www.arxiv.org/abs/2505.06262)

## About

Steering vectors allow users to modify activations at inference time to amplify or weaken a 'concept', e.g. honesty or positivity.

Dialz supports a diverse set of tasks, including creating contrastive pair datasets, computing and applying steering vectors, and visualizations.

A basic tutorial can be found [here](<notebooks/basic_tutorial.ipynb>).

## Installation

```
pip install dialz
```

Check out the [full documentation](https://cardiffnlp.github.io/dialz/) for usage information.

## Contributing

Any contributions to improve this project are welcome! Please open an issue or pull request in this repo with any changes you have.

## License

This code is released under a MIT license.
